@@ -1,7 +1,8 @@
 /* m-x.c -- Meta-x minibuffer reader.
-   $Id: m-x.c,v 1.1.1.1 2003/12/06 01:32:50 karl Exp $
+   $Id: m-x.c,v 1.3 2004/03/14 00:57:29 karl Exp $
 
-   Copyright (C) 1993, 1997, 1998, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1997, 1998, 2001, 2002, 2004 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,9 +33,7 @@
    name.  A return value of NULL indicates that no function name could
    be read. */
 char *
-read_function_name (prompt, window)
-     char *prompt;
-     WINDOW *window;
+read_function_name (char *prompt, WINDOW *window)
 {
   register int i;
   char *line;
@@ -71,7 +70,7 @@ DECLARE_INFO_COMMAND (describe_command,
 {
   char *line;
 
-  line = read_function_name (_("Describe command: "), window);
+  line = read_function_name ((char *) _("Describe command: "), window);
 
   if (!line)
     {
@@ -138,7 +137,8 @@ DECLARE_INFO_COMMAND (info_execute_command,
         (strncmp (line, "echo-area-", 10) == 0))
       {
         free (line);
-        info_error (_("Cannot execute an `echo-area' command here."));
+        info_error ((char *) _("Cannot execute an `echo-area' command here."),
+            NULL, NULL);
         return;
       }
 
