@@ -1,7 +1,7 @@
 /* sectioning.c -- for @chapter, @section, ..., @contents ...
-   $Id: sectioning.c,v 1.11 2004/02/20 02:42:19 dirt Exp $
+   $Id: sectioning.c,v 1.12 2004/03/12 18:21:06 karl Exp $
 
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -352,7 +352,7 @@ sectioning_underscore (char *cmd)
 	  get_rest_of_line (0, &temp);
           /* Use @settitle value if @top parameter is empty.  */
           if (STREQ (command, "top") && strlen(temp) == 0)
-            temp = xstrdup (title);
+            temp = xstrdup (title ? title : "");
 
           /* Docbook does not support @unnumbered at all.  So we provide numbers
              that other formats use.  @appendix seems to be fine though, so we let
