@@ -1,5 +1,5 @@
 /* xref.c -- cross references for Texinfo.
-   $Id: xref.c,v 1.8 2004/02/18 13:58:14 dirt Exp $
+   $Id: xref.c,v 1.9 2004/03/10 22:34:21 dirt Exp $
 
    Copyright (C) 2004 Free Software Foundation, Inc.
 
@@ -234,6 +234,15 @@ cm_xref (int arg)
                   /* html fixxme: revisit this; external node name not
                      much use to us with numbered nodes. */
                   add_html_elt ("<a href=");
+
+                  /* If there's a dot, make it a NULL terminator, so the
+                     extension does not get into the way.  */
+                  {
+                    char *p = strrchr (arg4 , '.');
+                    if (p != NULL)
+                      *p = 0;
+                  }
+
                   /* Note that if we are splitting, and the referenced
                      tag is an anchor rather than a node, we will
                      produce a reference to a file whose name is
@@ -242,7 +251,7 @@ cm_xref (int arg)
                      non-existent file.  cm_anchor, which see, deals
                      with that problem.  */
                   if (splitting)
-                    execute_string ("\"../%s/", arg4);
+                    execute_string ("\"%s/", arg4);
                   else
                     execute_string ("\"%s.html", arg4);
                   /* Do not collapse -- to -, etc., in references.  */
